@@ -1,32 +1,28 @@
 package Blog::Controller::Posts;
-use Mojo::Base 'Mojolicious::Controller';
+use Mojo::Base 'Mojolicious::Controller', -signatures;
 
-sub create { shift->render(post => {}) }
+sub create ($self) {
+  $self->render(post => {});
+}
 
-sub edit {
-  my $self = shift;
+sub edit ($self) {
   $self->render(post => $self->posts->find($self->param('id')));
 }
 
-sub index {
-  my $self = shift;
+sub index ($self) {
   $self->render(posts => $self->posts->all);
 }
 
-sub remove {
-  my $self = shift;
+sub remove ($self) {
   $self->posts->remove($self->param('id'));
   $self->redirect_to('posts');
 }
 
-sub show {
-  my $self = shift;
+sub show ($self) {
   $self->render(post => $self->posts->find($self->param('id')));
 }
 
-sub store {
-  my $self = shift;
-
+sub store ($self) {
   my $v = $self->_validation;
   return $self->render(action => 'create', post => {}) if $v->has_error;
 
@@ -34,9 +30,7 @@ sub store {
   $self->redirect_to('show_post', id => $id);
 }
 
-sub update {
-  my $self = shift;
-
+sub update ($self) {
   my $v = $self->_validation;
   return $self->render(action => 'edit', post => {}) if $v->has_error;
 
@@ -45,9 +39,7 @@ sub update {
   $self->redirect_to('show_post', id => $id);
 }
 
-sub _validation {
-  my $self = shift;
-
+sub _validation ($self) {
   my $v = $self->validation;
   $v->required('title', 'not_empty');
   $v->required('body',  'not_empty');
